@@ -2,7 +2,7 @@
 #'
 #' \code{fert} returns fertility indicators such as the Total Fertility Rate (TFR),
 #' General Fertility Rate (GFR), and Age Specific Fertility Rate (ASFR)
-#' \code{fert} returns the Standrad Error (SE), fertility exposure (N), weighted exposure (WN),
+#' \code{fert} returns the Standard Error (SE), fertility exposure (N), weighted exposure (WN),
 #' Design Effect (DEFT), Relative Standard Error (RSE), and Confidence Interval (CI).
 #'
 #' @author Mahmoud Elkasabi.
@@ -130,8 +130,6 @@ fert <- function(Data.Name, Indicator, JK = NULL, CL = NULL, Strata = NULL, Clus
   }
 
   Data.Name <- as.data.frame(Data.Name)
-  options(survey.lonely.psu = "adjust")
-
 
   if (Indicator == "tfr"){
     TFR(Data.Name, JK, CL, EverMW, AWFact, PeriodEnd, Period, Class)[[1]]
